import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { G as GetAppInstanceResponse, A as AppInstanceInstalledEnvelope, a as AppInstanceRemovedEnvelope, b as AppInstancePaidPlanAutoRenewalCancelledEnvelope, c as AppInstancePaidPlanChangedEnvelope, d as AppInstancePaidPlanPurchasedEnvelope, e as AppInstancePlanConvertedToPaidEnvelope, f as AppInstancePlanReactivatedEnvelope, g as AppInstancePlanTransferredEnvelope } from './devcenter-app-instance-v1-app-instance-app-instances.universal-Bfi1qsvM.js';
export { m as AppInstalled, j as AppInstance, n as AppRemoved, l as AvailablePlan, z as BaseEventMetadata, B as BillingInfo, k as FreeTrialInfo, h as FreeTrialPeriod, F as FreeTrialStatus, w as GetAppInstanceByInstanceIdRequest, u as GetAppInstanceRequest, I as IdentificationData, y as IdentificationDataIdOneOf, L as Locale, x as MessageEnvelope, M as Multilingual, O as OwnerInfo, q as PaidPlanAutoRenewalCancelled, p as PaidPlanChanged, o as PaidPlanPurchased, P as PaymentCycle, t as PlanConvertedToPaid, s as PlanReactivated, r as PlanTransferred, R as ReactivationReason, i as ResolutionMethod, S as SiteInfo, v as SupportedLanguage, W as WebhookIdentityType } from './devcenter-app-instance-v1-app-instance-app-instances.universal-Bfi1qsvM.js';

declare function getAppInstance$1(httpClient: HttpClient): GetAppInstanceSignature;
interface GetAppInstanceSignature {
    /**
     * Retrieves data about the instance of your app that's installed on a Wix
     * site and data about the site itself. For example, to check whether the Wix user has installed a free or paid version of your app,
     * or to check which apps made by Wix are installed on the site.
     *
     * You must authenticate this method [as a Wix app](https://dev.wix.com/docs/build-apps/develop-your-app/access/authentication/authenticate-using-oauth#step-2--make-an-authenticated-api-request).
     *
     * To retrieve `site.ownerInfo` in the response, you must
     * have the __READ SITE OWNER EMAIL__ permission scope in addition to
     * __MANAGE YOUR APP__.
     */
    (): Promise<GetAppInstanceResponse>;
}
declare const onAppInstanceInstalled$1: EventDefinition<AppInstanceInstalledEnvelope, "AppInstalled">;
declare const onAppInstanceRemoved$1: EventDefinition<AppInstanceRemovedEnvelope, "AppRemoved">;
declare const onAppInstancePaidPlanAutoRenewalCancelled$1: EventDefinition<AppInstancePaidPlanAutoRenewalCancelledEnvelope, "PaidPlanAutoRenewalCancelled">;
declare const onAppInstancePaidPlanChanged$1: EventDefinition<AppInstancePaidPlanChangedEnvelope, "PaidPlanChanged">;
declare const onAppInstancePaidPlanPurchased$1: EventDefinition<AppInstancePaidPlanPurchasedEnvelope, "PaidPlanPurchased">;
declare const onAppInstancePlanConvertedToPaid$1: EventDefinition<AppInstancePlanConvertedToPaidEnvelope, "PlanConvertedToPaid">;
declare const onAppInstancePlanReactivated$1: EventDefinition<AppInstancePlanReactivatedEnvelope, "PlanReactivated">;
declare const onAppInstancePlanTransferred$1: EventDefinition<AppInstancePlanTransferredEnvelope, "PlanTransferred">;

declare const getAppInstance: MaybeContext<BuildRESTFunction<typeof getAppInstance$1> & typeof getAppInstance$1>;
/**
 * Triggered when an instance of your app is installed on a Wix site.
 */
declare const onAppInstanceInstalled: BuildEventDefinition<typeof onAppInstanceInstalled$1>;
/**
 * Triggered when an instance of your app is uninstalled from a Wix site.
 */
declare const onAppInstanceRemoved: BuildEventDefinition<typeof onAppInstanceRemoved$1>;
/**
 * Triggered when a Wix user either cancels a paid plan for your app, or cancels the plan's auto-renewal. The
 * Wix user can continue to use your app until the end of the current billing
 * cycle.
 */
declare const onAppInstancePaidPlanAutoRenewalCancelled: BuildEventDefinition<typeof onAppInstancePaidPlanAutoRenewalCancelled$1>;
/**
 * Triggered when a Wix user upgrades or downgrades their plan for your app.
 */
declare const onAppInstancePaidPlanChanged: BuildEventDefinition<typeof onAppInstancePaidPlanChanged$1>;
/**
 * Triggered when a Wix user purchases a paid plan for your app.
 */
declare const onAppInstancePaidPlanPurchased: BuildEventDefinition<typeof onAppInstancePaidPlanPurchased$1>;
/**
 * Triggered when a Wix user reaches the end of a free-trial period and is charged successfully.
 */
declare const onAppInstancePlanConvertedToPaid: BuildEventDefinition<typeof onAppInstancePlanConvertedToPaid$1>;
/**
 * Triggered when auto-renewal is turned on for a paid plan.
 */
declare const onAppInstancePlanReactivated: BuildEventDefinition<typeof onAppInstancePlanReactivated$1>;
/**
 * Triggered when a paid plan for your app is transferred to a different Wix account.
 */
declare const onAppInstancePlanTransferred: BuildEventDefinition<typeof onAppInstancePlanTransferred$1>;

export { AppInstanceInstalledEnvelope, AppInstancePaidPlanAutoRenewalCancelledEnvelope, AppInstancePaidPlanChangedEnvelope, AppInstancePaidPlanPurchasedEnvelope, AppInstancePlanConvertedToPaidEnvelope, AppInstancePlanReactivatedEnvelope, AppInstancePlanTransferredEnvelope, AppInstanceRemovedEnvelope, GetAppInstanceResponse, getAppInstance, onAppInstanceInstalled, onAppInstancePaidPlanAutoRenewalCancelled, onAppInstancePaidPlanChanged, onAppInstancePaidPlanPurchased, onAppInstancePlanConvertedToPaid, onAppInstancePlanReactivated, onAppInstancePlanTransferred, onAppInstanceRemoved };
